@@ -1,6 +1,6 @@
 from pydantic import BaseModel, ConfigDict, Field, model_validator
-from typing import Self, TypeVar
-from maleo.types.base.dict import OptionalStringToStringDict
+from typing import Self, Set, TypeVar
+from maleo.types.base.dict import OptionalStringToStringDict, StringToAnyDict
 from maleo.types.base.integer import ListOfIntegers
 from maleo.types.base.string import OptionalString
 from maleo.utils.formatters.case import to_camel
@@ -14,6 +14,46 @@ class BasePoolingConfig(BaseModel):
 PoolingConfigT = TypeVar("PoolingConfigT", bound=BasePoolingConfig)
 
 
+class MySQLPoolingConfig(BasePoolingConfig):
+    """MySQL-specific pooling configuration."""
+
+    pool_size: int = Field(
+        default=8, ge=1, le=500, description="Number of connections in the pool"
+    )
+    max_overflow: int = Field(
+        default=15, ge=0, le=200, description="Maximum number of overflow connections"
+    )
+    pool_timeout: float = Field(
+        default=20.0,
+        ge=1.0,
+        le=300.0,
+        description="Timeout in seconds for getting connection",
+    )
+    pool_recycle: int = Field(
+        default=7200, ge=60, le=86400, description="Connection recycle time in seconds"
+    )
+    pool_pre_ping: bool = Field(
+        default=True, description="Validate connections before use"
+    )
+    strategy: PoolingStrategy = Field(
+        default=PoolingStrategy.FIXED, description="Pooling strategy"
+    )
+    # Add autocommit to pooling since it affects connection behavior in the pool
+    autocommit: bool = Field(default=False, description="Enable autocommit mode")
+    # Move connect_timeout here since it's about pool connection establishment
+    connect_timeout: float = Field(
+        default=10.0, ge=1.0, le=60.0, description="Connection timeout in seconds"
+    )
+
+    @property
+    def engine_kwargs_exclusions(self) -> Set[str]:
+        return {"strategy"}
+
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
+
+
 class PostgreSQLPoolingConfig(BasePoolingConfig):
     """PostgreSQL-specific pooling configuration."""
 
@@ -52,37 +92,17 @@ class PostgreSQLPoolingConfig(BasePoolingConfig):
             raise ValueError("max_overflow should not exceed 5x pool_size")
         return self
 
+    @property
+    def engine_kwargs_exclusions(self) -> Set[str]:
+        return {
+            "strategy",
+            "prepared_statement_cache_size",
+            "pool_reset_on_return",
+        }
 
-class MySQLPoolingConfig(BasePoolingConfig):
-    """MySQL-specific pooling configuration."""
-
-    pool_size: int = Field(
-        default=8, ge=1, le=500, description="Number of connections in the pool"
-    )
-    max_overflow: int = Field(
-        default=15, ge=0, le=200, description="Maximum number of overflow connections"
-    )
-    pool_timeout: float = Field(
-        default=20.0,
-        ge=1.0,
-        le=300.0,
-        description="Timeout in seconds for getting connection",
-    )
-    pool_recycle: int = Field(
-        default=7200, ge=60, le=86400, description="Connection recycle time in seconds"
-    )
-    pool_pre_ping: bool = Field(
-        default=True, description="Validate connections before use"
-    )
-    strategy: PoolingStrategy = Field(
-        default=PoolingStrategy.FIXED, description="Pooling strategy"
-    )
-    # Add autocommit to pooling since it affects connection behavior in the pool
-    autocommit: bool = Field(default=False, description="Enable autocommit mode")
-    # Move connect_timeout here since it's about pool connection establishment
-    connect_timeout: float = Field(
-        default=10.0, ge=1.0, le=60.0, description="Connection timeout in seconds"
-    )
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
 class SQLitePoolingConfig(BasePoolingConfig):
@@ -105,6 +125,18 @@ class SQLitePoolingConfig(BasePoolingConfig):
         default=30000, ge=1000, le=300000, description="Busy timeout in milliseconds"
     )
 
+    @property
+    def engine_kwargs_exclusions(self) -> Set[str]:
+        return {
+            "strategy",
+            "wal_mode",
+            "busy_timeout",
+        }
+
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
+
 
 class SQLServerPoolingConfig(BasePoolingConfig):
     """SQL Server-specific pooling configuration."""
@@ -152,60 +184,18 @@ class SQLServerPoolingConfig(BasePoolingConfig):
             raise ValueError("max_overflow should not exceed 3x pool_size")
         return self
 
+    @property
+    def engine_kwargs_exclusions(self) -> Set[str]:
+        return {
+            "connection_timeout",
+            "command_timeout",
+            "packet_size",
+            "trust_server_certificate",
+        }
 
-class MongoDBPoolingConfig(BasePoolingConfig):
-    """MongoDB-specific pooling configuration."""
-
-    model_config = ConfigDict(alias_generator=to_camel)
-
-    max_pool_size: int = Field(
-        default=100, ge=1, le=500, description="Maximum number of connections in pool"
-    )
-    min_pool_size: int = Field(
-        default=0, ge=0, le=100, description="Minimum number of connections in pool"
-    )
-    max_idle_time_ms: int = Field(
-        default=600000, ge=1000, le=3600000, description="Max idle time in milliseconds"
-    )
-    connect_timeout_ms: int = Field(
-        default=20000,
-        ge=1000,
-        le=300000,
-        description="Connection timeout in milliseconds",
-    )
-    server_selection_timeout_ms: int = Field(
-        default=30000, ge=1000, le=300000, description="Server selection timeout"
-    )
-    max_connecting: int = Field(
-        default=2,
-        ge=1,
-        le=10,
-        description="Maximum number of concurrent connection attempts",
-    )
-
-
-class RedisPoolingConfig(BasePoolingConfig):
-    """Redis-specific pooling configuration."""
-
-    max_connections: int = Field(
-        default=50, ge=1, le=1000, description="Maximum number of connections in pool"
-    )
-    retry_on_timeout: bool = Field(
-        default=True, description="Retry on connection timeout"
-    )
-    health_check_interval: int = Field(
-        default=30, ge=5, le=300, description="Health check interval in seconds"
-    )
-    connection_timeout: float = Field(
-        default=5.0, ge=1.0, le=60.0, description="Connection timeout in seconds"
-    )
-    socket_timeout: float = Field(
-        default=5.0, ge=1.0, le=60.0, description="Socket timeout in seconds"
-    )
-    socket_keepalive: bool = Field(default=True, description="Enable TCP keepalive")
-    decode_responses: bool = Field(
-        default=True, description="Decode responses to strings"
-    )
+    @property
+    def engine_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.engine_kwargs_exclusions, exclude_none=True)
 
 
 class ElasticsearchPoolingConfig(BasePoolingConfig):
@@ -253,3 +243,101 @@ class ElasticsearchPoolingConfig(BasePoolingConfig):
         if self.connections_per_node > self.maxsize:
             raise ValueError("connections_per_node must not exceed maxsize")
         return self
+
+    @property
+    def client_kwargs_exclusions(self) -> Set[str]:
+        return {
+            "connections_per_node",
+            "block",
+            "headers",
+            "dead_timeout",
+        }
+
+    @property
+    def client_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.client_kwargs_exclusions, exclude_none=True)
+
+
+class MongoDBPoolingConfig(BasePoolingConfig):
+    """MongoDB-specific pooling configuration."""
+
+    model_config = ConfigDict(alias_generator=to_camel)
+
+    max_pool_size: int = Field(
+        100,
+        ge=1,
+        le=500,
+        description="Maximum number of connections in pool",
+        alias="maxPoolSiza",
+    )
+    min_pool_size: int = Field(
+        0,
+        ge=0,
+        le=100,
+        description="Minimum number of connections in pool",
+        alias="minPoolSize",
+    )
+    max_idle_time_ms: int = Field(
+        600000,
+        ge=1000,
+        le=3600000,
+        description="Max idle time in milliseconds",
+        alias="maxIdleTimeMS",
+    )
+    connect_timeout_ms: int = Field(
+        20000,
+        ge=1000,
+        le=300000,
+        description="Connection timeout in milliseconds",
+        alias="connectTimeoutMS",
+    )
+    server_selection_timeout_ms: int = Field(
+        30000,
+        ge=1000,
+        le=300000,
+        description="Server selection timeout",
+        alias="serverSelectionTimeoutMS",
+    )
+    max_connecting: int = Field(
+        2,
+        ge=1,
+        le=10,
+        description="Maximum number of concurrent connection attempts",
+        alias="maxConnecting",
+    )
+
+    @property
+    def client_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(by_alias=True, exclude_none=True)
+
+
+class RedisPoolingConfig(BasePoolingConfig):
+    """Redis-specific pooling configuration."""
+
+    max_connections: int = Field(
+        default=50, ge=1, le=1000, description="Maximum number of connections in pool"
+    )
+    retry_on_timeout: bool = Field(
+        default=True, description="Retry on connection timeout"
+    )
+    health_check_interval: int = Field(
+        default=30, ge=5, le=300, description="Health check interval in seconds"
+    )
+    connection_timeout: float = Field(
+        default=5.0, ge=1.0, le=60.0, description="Connection timeout in seconds"
+    )
+    socket_timeout: float = Field(
+        default=5.0, ge=1.0, le=60.0, description="Socket timeout in seconds"
+    )
+    socket_keepalive: bool = Field(default=True, description="Enable TCP keepalive")
+    decode_responses: bool = Field(
+        default=True, description="Decode responses to strings"
+    )
+
+    @property
+    def client_kwargs_exclusions(self) -> Set[str]:
+        return {"health_check_interval"}
+
+    @property
+    def client_kwargs(self) -> StringToAnyDict:
+        return self.model_dump(exclude=self.client_kwargs_exclusions, exclude_none=True)
